@@ -1,7 +1,7 @@
 import json
 from django.db import models
 
-from ftp_deploy.utils.core import commits_parser
+from ftp_deploy.utils.repo import commits_parser
 from .service import Service
 
 class Log(models.Model):
@@ -15,7 +15,7 @@ class Log(models.Model):
 
     def commits_info(self):
         commits = json.loads(self.payload)['commits']
-        return commits_parser(commits).commits_info()
+        return commits_parser(commits,self.service.repo_source).commits_info()
 
     class Meta:
         ordering = ('-created',)
