@@ -5,7 +5,7 @@ from django.core.mail import EmailMultiAlternatives
 from django.template.loader import render_to_string
 
 from ftp_deploy.conf import *
-from .core import commits_parser
+from .repo import commits_parser, repository_parser
 from .curl import curl_connection
 
 
@@ -19,8 +19,8 @@ class notification():
         self.service = service
         self.payload = json.loads(payload)
         self.commits = self.payload['commits']
-        self.user = self.payload['user']
         self.from_email = 'noreply@ftpdeploy.com'
+        self.repo = repository_parser(self.payload, self.service)
         self.send()
 
     @property
@@ -43,20 +43,6 @@ class notification():
     def context(self):
         pass
 
-    def deploy_user(self):
-        """Method return email of deploy user"""
-        if self.payload['user'] == 'Restore':
-            return []
-
-        try:
-            curl = curl_connection(BITBUCKET_SETTINGS['username'], BITBUCKET_SETTINGS['password'])
-            curl.authenticate()
-            url = 'https://bitbucket.org/api/1.0/users/%s/emails' % self.payload['user']
-            context = json.loads(curl.perform(url))
-            return [context[0]['email']]
-        except Exception, e:
-            return []
-
     def send(self):
         """Sent method process emails from list returned by emails() method"""
 
@@ -87,10 +73,10 @@ class notification_success(notification):
             emails_list += notifications.get_success()
 
             if notifications.deploy_user_success():
-                emails_list += self.deploy_user()
+                emails_list += self.repo.deploy_email()
 
             if notifications.commit_user_success():
-                emails_list += commits_parser(self.commits).email_list()
+                emails_list += commits_parser(self.commits, self.service.repo_source).email_list()
 
         return list(set(emails_list))
 
@@ -98,8 +84,8 @@ class notification_success(notification):
         context = dict()
         context['service'] = self.service
         context['host'] = self.host
-        context['commits_info'] = commits_parser(self.commits).commits_info()
-        context['files_added'], context['files_modified'], context['files_removed'] = commits_parser(self.commits).file_diff()
+        context['commits_info'] = commits_parser(self.commits, self.service.repo_source).commits_info()
+        context['files_added'], context['files_modified'], context['files_removed'] = commits_parser(self.commits, self.service.repo_source).file_diff()
         return context
 
 
@@ -126,10 +112,10 @@ class notification_fail(notification):
             emails_list += notifications.get_fail()
 
             if notifications.deploy_user_fail():
-                emails_list += self.deploy_user()
+                emails_list += self.repo.deploy_email()
 
             if notifications.commit_user_fail():
-                emails_list += commits_parser(self.commits).email_list()
+                emails_list += commits_parser(self.commits, self.service.repo_source).email_list()
 
         return list(set(emails_list))
 
