@@ -11,11 +11,10 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 
 from .models import Service, Log, Task
-from .utils.core import absolute_url
 from .tasks import deploy_task
+from .utils.core import absolute_url
 from .utils.deploy import Deploy
-
-import time
+from .utils.repo import repository_parser
 
 
 class DeployView(View):
@@ -33,29 +32,16 @@ class DeployView(View):
         return super(DeployView, self).dispatch(*args, **kwargs)
 
     def post(self, request, *args, **kwargs):
-
         json_string = request.POST['payload'].decode('string_escape').replace('\n', '')
         data = json.loads(json_string)
 
-        if(self.check_branch(data)):
+        if(repository_parser(data, self.service).check_branch()):
             host = absolute_url(request).build()
             job = deploy_task.apply_async((host, json_string, self.service), countdown=1)
             Task.objects.create(name=job.id, service=self.service)
 
         return HttpResponse(status=200)
 
-    def check_branch(self, data):
-        """check if payload branch match set branch"""
-        if self.service.repo_source == 'bb':
-            last_commit = len(data['commits']) - 1
-            if data['commits'][last_commit]['branch'] == self.service.repo_branch:
-                return True
-
-        if self.service.repo_source == 'gh':
-            pass
-
-        return False
-
 
 class DeployStatusView(DeployView):
 
@@ -69,4 +55,3 @@ class DeployStatusView(DeployView):
         data['queue'] = self.service.task_set.all().count()
         json_data = json.dumps(data)
         return HttpResponse(json_data, mimetype='application/json')
-
